Crate sonicapi

Modules

alu
embedded
sigs

Structs

AnnotationName
Annotations
ApiId
ApiInner
API is an interface implementation.
AppendApi
API for append-only state.
Articles
Articles contain the contract and all related codex and API information for interacting with it.
Builder
BuilderRef
CallRequest
Call request provides information for constructing [hypersonic::CallParams].
CallState
Combination of a method name and an optional state name used in API requests.
CoreParams
DataCell
DestructibleApi
IssueParams
NamedState
OpBuilder
OpBuilderRef
Schema
Schema contains information required for creation of a contract.
StateAtom
StructData

Enums

Api
CallScope
Endpoint
MergeError
StateCalcError
VmType

Constants

LIB_NAME_SONIC

Traits

ApiVm
StateAdaptor
Adaptors convert field elements into structured data and vise verse.
StateArithm
StateCalc
StateReader
Reader constructs a composite state out of distinct values of all appendable state elements of the same type.

Type Aliases

MethodName
StateName
StateTy