Struct Site

pub struct Site<Id>
where Id: SiteId,
{ pub prog_id: Id, pub offset: u16, }
Location inside the instruction sequence which can be executed by the core.

This type is required in addition to crate::LibSite in order to achieve proper abstraction, layering, and separation of concerns: the core must know nothing about library structure.

Fields

prog_id: Id

Identifier of the program.

offset: u16

Offset in the code segment within the program.

Implementations

Source

impl<Id> Site<Id>
where Id: SiteId,

pub fn new(prog_id: Id, offset: u16) -> Site<Id>

Construct a new code site out of program identifier and code offset.