Module gfa

Galois field arithmetic ISA

Enums

Bits
Maximum bit dimension which a register value should fit (used in FieldInstr::Fits instruction).
ConstVal
A predefined constant field element for a register initialization.
FieldInstr
Arithmetic instructions for finite fields.
Instr
Instruction set, which includes core AluVM control-flow instructions and GFA256 ISA extension (see FieldInstr).

Constants

ISA_GFA256
AluVM ISA extension name.