Enum Bits

#[repr(u8)]
pub enum Bits { Bits8 = 0, Bits16 = 1, Bits24 = 2, Bits32 = 3, Bits48 = 4, Bits64 = 5, Bits96 = 6, Bits128 = 7, }
Maximum bit dimension which a register value should fit (used in FieldInstr::Fits instruction).

Variants



Bits8 = 0

8 bits (a byte).



Bits16 = 1

16 bits (two bytes).



Bits24 = 2

24 bits (three bytes).



Bits32 = 3

32 bits (four bytes).



Bits48 = 4

48 bits (six bytes).



Bits64 = 5

64 bits (8 bytes).



Bits96 = 6

96 bits (12 bytes).



Bits128 = 7

128 bits (16 bytes).

Implementations

Source

impl Bits

pub const fn to_u3(self) -> u3

Get a 3-bit representation of the bit dimension variant.

pub fn from_bit_len(len: usize) -> Bits

Construct a dimension variant a bit out of bit length.

Panics

If there is no enum variant matching the provided bit length.

pub const fn bit_len(self) -> usize

Returns a bit length corresponding to the enum variant.