Enum FieldInstr

#[non_exhaustive]
pub enum FieldInstr { Test { src: RegE, }, Clr { dst: RegE, }, PutD { dst: RegE, data: fe256, }, PutZ { dst: RegE, }, PutV { dst: RegE, val: ConstVal, }, Fits { src: RegE, bits: Bits, }, Mov { dst: RegE, src: RegE, }, Eq { src1: RegE, src2: RegE, }, Neg { dst: RegE, src: RegE, }, Add { dst_src: RegE, src: RegE, }, Mul { dst_src: RegE, src: RegE, }, }
Arithmetic instructions for finite fields.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Test

Tests if register contains a value and is not set to None.

Sets CO register to [Status::Ok] if a register contains a value, and to [Status::Fail] otherwise.

Does not affect the value in the CK register.

Fields

src: RegE

The source register



Clr

Clears register value by setting it to None.

Does not affect values in the CO and CK registers.

Fields

dst: RegE

The destination register



PutD

Puts value into a register, replacing the previous value in it if there was any.

Does not affect values in the CO and CK registers.

Fields

dst: RegE

The destination register

data: fe256

Finite field element taken from the data segment, used to initialize the register



PutZ

Puts zero (0) value into a register, replacing the previous value in it if there was any.

Does not affect values in the CO and CK registers.

Fields

dst: RegE

The destination register



PutV

Puts val value, which is a power of 2, into a register, replacing the previous value in it if there was any.

Does not affect values in the CO and CK registers.

Fields

dst: RegE

The destination register

val: ConstVal

A constant finite field element used to initialize the register



Fits

Test whether a value in a register fits in the provided number of bits.

Sets CO register to [Status::Ok] if the value fits the given number of bits, and to [Status::Fail] otherwise.

If src is set to None, sets both CO and CK to [Status::Fail]; otherwise leaves value in the CK unchanged.

Fields

src: RegE

The source register

bits: Bits

The maximum bit dimension which the source register value must fit into



Mov

Moves (copies) value from src to dst register, overwriting the previous value in dst. If src has no value (i.e., set to None), sets dst to None.

Leaves the state of the src register unaffected.

Does not affect values in the CO and CK registers.

Fields

dst: RegE

The destination register

src: RegE

The source register



Eq

Checks whether src1 and src2 registers are equal.

Sets CO register to represent equivalence of the registers. If both src1 and src2 registers contain no value, sets CK to a failed state.

Does not affect the value in the CK register.

Fields

src1: RegE

The first source register

src2: RegE

The second source register



Neg

Negate value in src using finite-field arithmetics, and put result into dst.

Does not affect values in the CO register.

If src is set to None, sets CK to [Status::Fail]; otherwise leaves value in CK unchanged.

Fields

dst: RegE

The destination register

src: RegE

The source register



Add

Add src value to dst_src value using finite-field (modulo) arithmetics of the FQ order, putting the result to dst_src.

Does not affect values in the CO register.

If either src or dst_src (or both) is set to None, sets CK to [Status::Fail]; otherwise leaves value in the CK unchanged.

Fields

dst_src: RegE

The first source and the destination register

src: RegE

The second source register



Mul

Multiply src value to dst_src value using finite-field (modulo) arithmetics of the FQ order, putting the result to dst_src.

Does not affect values in the CO register.

If either src or dst_src (or both) is set to None, sets CK to [Status::Fail]; otherwise leaves value in the CK unchanged.

Fields

dst_src: RegE

The first source and the destination register

src: RegE

The second source register

Implementations

Source

impl FieldInstr

pub const START: u8 = 64u8

The initial value of the instruction op codes.

pub const END: u8 = 69u8

The ending value of the instruction op codes.

pub const SET: u8 = 64u8

pub const TEST: u8 = 64u8

pub const CLR: u8 = 64u8

pub const PUTD: u8 = 64u8

pub const PUTZ: u8 = 64u8

pub const PUTV: u8 = 64u8

pub const FITS: u8 = 64u8

pub const MOV: u8 = 65u8

pub const EQ: u8 = 66u8

pub const NEG: u8 = 67u8

pub const ADD: u8 = 68u8

pub const MUL: u8 = 69u8