#[non_exhaustive]pub enum UsonicInstr {
CkNxIRo,
CkNxIAo,
CkNxORo,
CkNxOAo,
LdIRo,
LdIAo,
LdORo,
LdOAo,
RstIRo,
RstIAo,
RstORo,
RstOAo,
}Expand description
The instruction set uses iterator semantics and not random access semantic to correspond to the RISC type of the machine and not to add assumptions about abilities to access the operation state in a random way. Operation state is always iterated, such that not a single state element can be missed (as long as iterator runs to the end).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CkNxIRo
Checks whether there is a next destructible memory cell in the contract state listed in the
operation input and sets CO register accordingly.
CkNxIAo
Checks whether there is a next immutable memory cell in the contract state listed in the
operation input and sets CO register accordingly.
CkNxORo
Checks whether there is a next destructible memory cell defined by the operation and sets
CO register accordingly.
CkNxOAo
Checks whether there is a next immutable memory cell defined by the operation and sets CO
register accordingly.
LdIRo
Load next [StateValue] from the current input destructible memory cell to EA-ED
registers.
If the next state value is absent, sets CO to a failed state. Otherwise, resets CO.
LdIAo
Load next [StateValue] from the current input immutable memory cell to EA-ED
registers.
If the next state value is absent, sets CO to a failed state. Otherwise, resets CO.
LdORo
Load next [StateValue] from the current output destructible memory cell to EA-ED
registers.
If the next state value is absent, sets CO to a failed state. Otherwise, resets CO.
LdOAo
Load next [StateValue] from the current output immutable memory cell to EA-ED
registers.
If the next state value is absent, sets CO to a failed state. Otherwise, resets CO.
RstIRo
Resets iterator over input destructible memory cells by setting corresponding UI value to
zero.
Does not affect the value of CO or CK registers.
RstIAo
Resets iterator over input immutable memory cells by setting corresponding UI value to
zero.
Does not affect the value of CO or CK registers.
RstORo
Resets iterator over output destructible memory cells by setting corresponding UI value
to zero.
Does not affect the value of CO or CK registers.
RstOAo
Resets iterator over output immutable memory cells by setting corresponding UI value to
zero.
Does not affect the value of CO or CK registers.