pub struct AppendApi<Vm: ApiVm> {
pub sem_id: SemId,
pub raw_sem_id: SemId,
pub published: bool,
pub adaptor: Vm::Adaptor,
}Expand description
API for append-only state.
API covers two main functions: taking structured data from the user input and building a valid state included into a new contract operation - and taking contract state and converting it into a user-friendly form, as a structured data (which may be lately used by readers performing aggregation of state into a collection-type objects).
Fields
sem_id: SemIdSemantic type id for verifiable part of the state.
raw_sem_id: SemIdSemantic type id for non-verifiable part of the state.
published: booladaptor: Vm::AdaptorProcedures which convert a state made of finite field elements StateData into a
structured type [StructData] and vice verse.
Implementations
Sourceimpl<Vm: ApiVm> AppendApi<Vm>
impl<Vm: ApiVm> AppendApi<Vm>
pub fn convert(&self, data: &StateData, sys: &TypeSystem) -> Option<StateAtom>
Sourcepub fn build(
&self,
value: StrictVal,
raw: Option<StrictVal>,
sys: &TypeSystem,
) -> StateData
pub fn build( &self, value: StrictVal, raw: Option<StrictVal>, sys: &TypeSystem, ) -> StateData
Build an immutable memory cell out of structured state.
Since append-only state includes both field elements (verifiable part of the state) and optional structured data (non-verifiable, non-compressible part of the state) it takes two inputs of a structured state data, leaving the raw part unchanged.