pub struct DestructibleApi<Vm: ApiVm> {
pub sem_id: SemId,
pub arithmetics: Vm::Arithm,
pub adaptor: Vm::Adaptor,
}Fields
sem_id: SemIdarithmetics: Vm::ArithmState arithmetics engine used in constructing new contract operations.
adaptor: Vm::AdaptorProcedures which convert a state made of finite field elements StateData into a
structured type [StructData] and vice verse.
Implementations
Sourceimpl<Vm: ApiVm> DestructibleApi<Vm>
impl<Vm: ApiVm> DestructibleApi<Vm>
pub fn convert(&self, value: StateValue, sys: &TypeSystem) -> Option<StrictVal>
pub fn build(&self, value: StrictVal, sys: &TypeSystem) -> StateValue
pub fn arithmetics(&self) -> &Vm::Arithm