Modules
Structs
- Annotation
Name - Annotations
- ApiId
- ApiInner
- API is an interface implementation.
- Append
Api - API for append-only state.
- Articles
- Articles contain the contract and all related codex and API information for interacting with it.
- Builder
- Builder
Ref - Call
Request - Call request provides information for constructing [
hypersonic::CallParams]. - Call
State - Combination of a method name and an optional state name used in API requests.
- Core
Params - Data
Cell - Destructible
Api - Issue
Params - Named
State - OpBuilder
- OpBuilder
Ref - Schema
- Schema contains information required for creation of a contract.
- State
Atom - Struct
Data
Enums
Constants
Traits
- ApiVm
- State
Adaptor - Adaptors convert field elements into structured data and vise verse.
- State
Arithm - State
Calc - State
Reader - Reader constructs a composite state out of distinct values of all appendable state elements of the same type.