Crate sonicapi

Modules

alu
aluvm
embedded
sigs
stl

Macros

uasm
Macro compiler for AluVM assembler.

Structs

AnnotationName
Annotations
ApiId
ApiInner
AppendApi
API for append-only state.
Articles
Articles contain the contract and all related codex and API information for interacting with it.
AuthToken
Builder
BuilderRef
CallRequest
Call request provides information for constructing [hypersonic::CallParams].
CallState
Combination of a method name and an optional state name used in API requests.
CellAddr
Codex
Codex is a crucial part of a contract; it provides a set of commitments to the contract terms and conditions expressed as a deterministic program able to run in SONIC computer model.
CodexId
Unique codex identifier - a commitment to all codex data
ConstU32
ContractId
Unique contract identifier equivalent to the contract genesis commitment
ContractMeta
CoreParams
DataCell
DestructibleApi
Genesis
GenesisId
Identity
An ASCII printable string up to 4096 chars representing identity of a developer.
Input
IoCat
Issue
IssueParams
NamedState
OpBuilder
OpBuilderRef
Operation
Opid
Unique operation (genesis, extensions & state transition) identifier equivalent to the commitment hash
RawData
Schema
A schema contains information required for the creation of a contract.
StateAtom
StateCell
Read-once access-controlled memory cell.
StateData
StructData
UsonicCore
VerifiedOperation
VmContext
fe256

Enums

Api
API is an interface implementation.
CallError
CallScope
Consensus
ContractName
Endpoint
Instr
MergeError
ParseAddrError
StateCalcError
StateValue
UsonicInstr
The instruction set uses iterator semantics and not random access semantic to correspond to the RISC type of the machine and not to add assumptions about abilities to access the operation state in a random way. Operation state is always iterated, such that not a single state element can be missed (as long as iterator runs to the end).
VmType

Constants

ARTICLES_MAGIC_NUMBER
ARTICLES_VERSION
ISA_ULTRASONIC
LIB_NAME_SONIC
LIB_NAME_ULTRASONIC
SCHEMA_MAGIC_NUMBER
SCHEMA_VERSION

Traits

ApiVm
LibRepo
Memory
StateAdaptor
Adaptors convert field elements into structured data and vise verse.
StateArithm
StateCalc
StateReader
Reader constructs a composite state out of distinct values of all appendable state elements of the same type.

Type Aliases

AccessId
CallId
MethodName
StateName
StateTy