Modules
Macros
- uasm
- Macro compiler for AluVM assembler.
Structs
- Annotation
Name - Annotations
- ApiId
- ApiInner
- Append
Api - API for append-only state.
- Articles
- Articles contain the contract and all related codex and API information for interacting with it.
- Auth
Token - Builder
- Builder
Ref - Call
Request - Call request provides information for constructing [
hypersonic::CallParams]. - Call
State - Combination of a method name and an optional state name used in API requests.
- Cell
Addr - Codex
- Codex is a crucial part of a contract; it provides a set of commitments to the contract terms and conditions expressed as a deterministic program able to run in SONIC computer model.
- CodexId
- Unique codex identifier - a commitment to all codex data
- Const
U32 - Contract
Id - Unique contract identifier equivalent to the contract genesis commitment
- Contract
Meta - Core
Params - Data
Cell - Destructible
Api - Genesis
- Genesis
Id - Identity
- An ASCII printable string up to 4096 chars representing identity of a developer.
- Input
- IoCat
- Issue
- Issue
Params - Named
State - OpBuilder
- OpBuilder
Ref - Operation
- Opid
- Unique operation (genesis, extensions & state transition) identifier equivalent to the commitment hash
- RawData
- Schema
- A schema contains information required for the creation of a contract.
- State
Atom - State
Cell - Read-once access-controlled memory cell.
- State
Data - Struct
Data - Usonic
Core - Verified
Operation - VmContext
- fe256
Enums
- Api
- API is an interface implementation.
- Call
Error - Call
Scope - Consensus
- Contract
Name - Endpoint
- Instr
- Merge
Error - Parse
Addr Error - State
Calc Error - State
Value - Usonic
Instr - The instruction set uses iterator semantics and not random access semantic to correspond to the RISC type of the machine and not to add assumptions about abilities to access the operation state in a random way. Operation state is always iterated, such that not a single state element can be missed (as long as iterator runs to the end).
- VmType
Constants
- ARTICLES_
MAGIC_ NUMBER - ARTICLES_
VERSION - ISA_
ULTRASONIC - LIB_
NAME_ SONIC - LIB_
NAME_ ULTRASONIC - SCHEMA_
MAGIC_ NUMBER - SCHEMA_
VERSION
Traits
- ApiVm
- LibRepo
- Memory
- State
Adaptor - Adaptors convert field elements into structured data and vise verse.
- State
Arithm - State
Calc - State
Reader - Reader constructs a composite state out of distinct values of all appendable state elements of the same type.