#[non_exhaustive]pub enum FieldInstr {
Test {
src: RegE,
},
Clr {
dst: RegE,
},
PutD {
dst: RegE,
data: fe256,
},
PutZ {
dst: RegE,
},
PutV {
dst: RegE,
val: ConstVal,
},
Fits {
src: RegE,
bits: Bits,
},
Mov {
dst: RegE,
src: RegE,
},
Eq {
src1: RegE,
src2: RegE,
},
Neg {
dst: RegE,
src: RegE,
},
Add {
dst_src: RegE,
src: RegE,
},
Mul {
dst_src: RegE,
src: RegE,
},
}Expand description
Arithmetic instructions for finite fields.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Test
Tests if register contains a value and is not set to None.
Sets CO register to [Status::Ok] if a register contains a value, and to [Status::Fail]
otherwise.
Does not affect the value in the CK register.
Clr
Clears register value by setting it to None.
Does not affect values in the CO and CK registers.
PutD
Puts value into a register, replacing the previous value in it if there was any.
Does not affect values in the CO and CK registers.
Fields
PutZ
Puts zero (0) value into a register, replacing the previous value in it if there was any.
Does not affect values in the CO and CK registers.
PutV
Puts val value, which is a power of 2, into a register, replacing the previous value in
it if there was any.
Does not affect values in the CO and CK registers.
Fields
Fits
Test whether a value in a register fits in the provided number of bits.
Sets CO register to [Status::Ok] if the value fits the given number of bits, and to
[Status::Fail] otherwise.
If src is set to None, sets both CO and CK to [Status::Fail]; otherwise leaves
value in the CK unchanged.
Fields
Mov
Moves (copies) value from src to dst register, overwriting the previous value in dst.
If src has no value (i.e., set to None), sets dst to None.
Leaves the state of the src register unaffected.
Does not affect values in the CO and CK registers.
Eq
Checks whether src1 and src2 registers are equal.
Sets CO register to represent equivalence of the registers. If both src1 and src2
registers contain no value, sets CK to a failed state.
Does not affect the value in the CK register.
Neg
Negate value in src using finite-field arithmetics, and put result into dst.
Does not affect values in the CO register.
If src is set to None, sets CK to [Status::Fail]; otherwise leaves value in CK
unchanged.
Add
Add src value to dst_src value using finite-field (modulo) arithmetics of the FQ
order, putting the result to dst_src.
Does not affect values in the CO register.
If either src or dst_src (or both) is set to None, sets CK to [Status::Fail];
otherwise leaves value in the CK unchanged.
Fields
Mul
Multiply src value to dst_src value using finite-field (modulo) arithmetics of the
FQ order, putting the result to dst_src.
Does not affect values in the CO register.
If either src or dst_src (or both) is set to None, sets CK to [Status::Fail];
otherwise leaves value in the CK unchanged.
Implementations
Sourceimpl FieldInstr
impl FieldInstr
pub const SET: u8 = 64u8
pub const TEST: u8 = 64u8
pub const CLR: u8 = 64u8
pub const PUTD: u8 = 64u8
pub const PUTZ: u8 = 64u8
pub const PUTV: u8 = 64u8
pub const FITS: u8 = 64u8
pub const MOV: u8 = 65u8
pub const EQ: u8 = 66u8
pub const NEG: u8 = 67u8
pub const ADD: u8 = 68u8
pub const MUL: u8 = 69u8