#[non_exhaustive]pub enum FieldInstr {
Test {
src: RegE,
},
Clr {
dst: RegE,
},
PutD {
dst: RegE,
data: fe256,
},
PutZ {
dst: RegE,
},
PutV {
dst: RegE,
val: ConstVal,
},
Fits {
src: RegE,
bits: Bits,
},
Mov {
dst: RegE,
src: RegE,
},
Eq {
src1: RegE,
src2: RegE,
},
Neg {
dst: RegE,
src: RegE,
},
Add {
dst_src: RegE,
src: RegE,
},
Mul {
dst_src: RegE,
src: RegE,
},
}Expand description
Arithmetic instructions for finite fields.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Test
Tests if register contains a value and is not set to None.
Sets CO register to [Status::Ok] if a register contains a value, and to [Status::Fail]
otherwise.
Doesn’t affect value in CK register.
Clr
Clears register value by setting it to None.
Doesn’t affect values in CO and CK registers.
PutD
Puts value into a register, replacing previous value in it, if there was any.
Doesn’t affect values in CO and CK registers.
PutZ
Puts zero (0) value into a register, replacing previous value in it, if there was any.
Doesn’t affect values in CO and CK registers.
PutV
Puts val value, which is a power of 2, into a register, replacing previous value in it, if
there was any.
Doesn’t affect values in CO and CK registers.
Fits
Test whether a value in a register fits in the provided number of bits.
Sets CO register to [Status::Ok] if the value fits given number of bits, and to
[Status::Fail] otherwise.
If src is set to None, sets both CO and CK to [Status::Fail]; otherwise leaves
value in CK unchanged.
Mov
Moves (copies) value from src to dst register, overwriting previous value in dst. If
src has no value (i.e. set to None), sets dst to None. State of src register
remains unaffected.
Doesn’t affect values in CO and CK registers.
Eq
Checks whether src1 and src2 registers are equal. If both src1 and src2 registers
contain no value, considers them equal.
Sets CO register to represent equivalence of the registers.
Doesn’t affect value in CK register.
Neg
Negate value in src using finite-field arithmetics, and put result into dst.
Doesn’t affect values in CO register.
If src is set to None, sets CK to [Status::Fail]; otherwise leaves value in CK
unchanged.
Add
Add src value to dst_src value using finite-field (modulo) arithmetics of the order,
putting result to dst_src.
Doesn’t affect values in CO register.
If either src or dst_src (or both) is set to None, sets CK to [Status::Fail];
otherwise leaves value in CK unchanged.
Mul
Multiply src value to dst_src value using finite-field (modulo) arithmetics of the
order, putting result to dst_src.
Doesn’t affect values in CO register.
If either src or dst_src (or both) is set to None, sets CK to [Status::Fail];
otherwise leaves value in CK unchanged.