pub struct ApiInner<Vm: ApiVm> {Show 13 fields
pub version: ReservedBytes<2>,
pub codex_id: CodexId,
pub timestamp: i64,
pub name: Option<TypeName>,
pub developer: Identity,
pub conforms: Option<TypeName>,
pub default_call: Option<CallState>,
pub reserved: ReservedBytes<8>,
pub append_only: TinyOrdMap<StateName, AppendApi<Vm>>,
pub destructible: TinyOrdMap<StateName, DestructibleApi<Vm>>,
pub readers: TinyOrdMap<MethodName, Vm::Reader>,
pub verifiers: TinyOrdMap<MethodName, CallId>,
pub errors: TinyOrdMap<u256, TinyString>,
}Fields
version: ReservedBytes<2>Version of the API structure.
codex_id: CodexIdCommitment to the codex under which the API is valid.
timestamp: i64Timestamp, which is used for versioning (later APIs have priority over new ones).
name: Option<TypeName>API name. Each codex must have a default API with no name.
developer: IdentityDeveloper identity string.
conforms: Option<TypeName>Interface standard to which the API conforms.
default_call: Option<CallState>Name for the default API call and destructible state name.
reserved: ReservedBytes<8>Reserved for future use.
append_only: TinyOrdMap<StateName, AppendApi<Vm>>State API defines how a structured contract state is constructed out of (and converted into) UltraSONIC immutable memory cells.
destructible: TinyOrdMap<StateName, DestructibleApi<Vm>>State API defines how a structured contract state is constructed out of (and converted into) UltraSONIC destructible memory cells.
readers: TinyOrdMap<MethodName, Vm::Reader>Readers have access to the converted global state and can construct a derived state out of
it.
The typical examples when readers are used are to sum individual asset issues and compute the number of totally issued assets.
verifiers: TinyOrdMap<MethodName, CallId>Links between named transaction methods defined in the interface - and corresponding verifier call ids defined by the contract.
NB: Multiple methods from the interface may call the came verifier.
errors: TinyOrdMap<u256, TinyString>Maps error type reported by a contract verifier via EA value to an error description taken
from the interfaces.