pub trait StateReader:
Clone
+ Ord
+ Debug
+ StrictDumb
+ StrictEncode
+ StrictDecode
+ Serde {
// Required method
fn read<'s, I: IntoIterator<Item = &'s StateAtom>>(
&self,
state: impl Fn(&StateName) -> I,
) -> StrictVal;
}Expand description
Reader constructs a composite state out of distinct values of all appendable state elements of the same type.
Required Methods
fn read<'s, I: IntoIterator<Item = &'s StateAtom>>( &self, state: impl Fn(&StateName) -> I, ) -> StrictVal
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.